MorphPair class final

Describes a morph from from to to without owning animation state.

Constructors

MorphPair(String from, String to)
Creates a source/target pair.
const

Properties

from String
Source icon d attribute.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to String
Target icon d attribute.
final

Methods

canvas({required double progress, double size = 24, Color? color, double strokeWidth = 2, double viewBox = 24, String? semanticLabel}) MorphCanvas
Builds a controlled MorphCanvas at progress.
icon({required double progress, double size = 24, double strokeWidth = 2, Color? color, String? semanticLabel}) MorphIcon
Builds a controlled MorphIcon at progress.
mask({required Widget child, required double progress, Color color = const Color(0xFFFFFFFF), double strokeWidth = 2, double viewBox = 24, String? semanticLabel}) MorphMask
Builds a controlled MorphMask at progress around child.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
tween() MorphTween
Creates the pure, ticker-free interpolator for this pair.

Operators

operator ==(Object other) bool
The equality operator.
inherited